@@ -6,8 +6,8 @@
 #' an affirmative action.
 #'
 #' The objects are first pasted without separators
-#' and collapsed using \code{\link{paste0}(..., collapse = "")}
-#' before being output using \code{\link{cat}}.
+#' and collapsed using `[paste0](..., collapse = "")`
+#' before being output using [cat()].
 #'
 #' The order and phrasing of the possible responses varies randomly to ensure
 #' the user consciously chooses (as opposed to automatically types their response).
@@ -23,20 +23,22 @@
 #'
 #' @param ... Objects to paste and then output to produce the question.
 #' @return A flag indicating whether the user answered yes or no.
-#' @seealso \code{\link{yesno2}}
+#' @seealso [yesno2()]
 #' @export
 #' @examples
-#'\dontrun{
-#' yesno("Do you like ", R.Version()$nickname ,"?")
-#'}
+#' \dontrun{
+#' yesno("Do you like ", R.Version()$nickname, "?")
+#' }
 yesno <- function(...) {
-  yeses <- c("Yes", "Definitely", "For sure", "Yup", "Yeah",
-             "I agree", "Absolutely")
+  yeses <- c(
+    "Yes", "Definitely", "For sure", "Yup", "Yeah",
+    "I agree", "Absolutely"
+  )
   nos <- c("No way", "Not yet", "I forget", "No", "Nope", "Uhhhh... Maybe?")
 
   qs <- c(sample(yeses, 1), sample(nos, 2))
   rand <- sample(length(qs))
 
   cat(paste0(..., collapse = ""))
-  menu(qs[rand]) == which(rand == 1)
+  utils::menu(qs[rand]) == which(rand == 1)
 }
