@@ -6,29 +6,31 @@
 #' one of two affirmative options.
 #'
 #' The objects are first pasted without separators
-#' and collapsed using \code{\link{paste0}(..., collapse = "")}
-#' before being output using \code{\link{cat}}.
+#' and collapsed using `[paste0](..., collapse = "")`
+#' before being output using [cat()].
 #'
 #' Selection of a 0 (to exit) causes the code to throw an error.
 #'
-#' @param ... Objects to paste and then output to produce the question.
+#' @inheritParams yesno
 #' @param yes A string of the first response.
 #' @param no A string of the second response.
 #' @return A flag indicating whether the user selected the first (TRUE) or second (FALSE) response.
-#' @seealso \code{\link{yesno}}
+#' @seealso [yesno()]
 #' @export
 #' @examples
-#'\dontrun{
+#' \dontrun{
 #' yesno2("Do you like this question?", yes = "I really do")
-#'}
+#' }
 yesno2 <- function(..., yes = "Yes", no = "No") {
-  if(!(is.character(yes) && identical(length(yes), 1L)) && isTRUE(!is.na(yes)))
+  if (!(is.character(yes) && identical(length(yes), 1L)) && isTRUE(!is.na(yes))) {
     stop("yes must be a string", call. = FALSE)
-  if(!(is.character(no) && identical(length(no), 1L)) && isTRUE(!is.na(no)))
+  }
+  if (!(is.character(no) && identical(length(no), 1L)) && isTRUE(!is.na(no))) {
     stop("no must be a string", call. = FALSE)
+  }
 
   cat(paste0(..., collapse = ""))
-  response <- menu(c(yes, no))
+  response <- utils::menu(c(yes, no))
   if (response == 0) stop("user choose to exit")
   response == 1
 }
